# FAP
list_soft_interlocks = [
    "DCCT 1 Fault",
    "DCCT 2 Fault",
    "DCCT High Difference",
    "Load Feedback 1 Fault",
    "Load Feedback 2 Fault",
    "IGBTs Current High Difference",
]

list_hard_interlocks = [
    "Load Overcurrent",
    "Load Overvoltage",
    "DCLink Overvoltage",
    "DCLink Undervoltage",
    "Welded Contactor Fault",
    "Opened Contactor Fault",
    "IGBT 1 Overcurrent",
    "IGBT 2 Overcurrent",
    "IIB Itlk",
]

list_iib_interlocks = [
    "Input Overvoltage",
    "Output Overvoltage",
    "IGBT 1 Overcurrent",
    "IGBT 2 Overcurrent",
    "IGBT 1 Overtemperature",
    "IGBT 2 Overtemperature",
    "Driver Overvoltage",
    "Driver 1 Overcurrent",
    "Driver 2 Overcurrent",
    "Driver 1 Error",
    "Driver 2 Error",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "DCLink Contactor Fault",
    "Contact Sticking of Contactor",
    "External Interlock",
    "Rack Interlock",
    "High Leakage Current",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

list_iib_alarms = [
    "Input Overvoltage",
    "Output Overvoltage",
    "IGBT 1 Overcurrent",
    "IGBT 2 Overcurrent",
    "IGBT 1 Overtemperature",
    "IGBT 2 Overtemperature",
    "Driver Overvoltage",
    "Driver 1 Overcurrent",
    "Driver 2 Overcurrent",
    "Inductors Overtemperature",
    "Heat-Sink Overtemperature",
    "High Leakage Current",
    "Board IIB Overtemperature",
    "Module Overhumidity",
]

# FAP-4P
list_4p_soft_interlocks = [
    "DCCT 1 Fault",
    "DCCT 2 Fault",
    "DCCT High Difference",
    "Load Feedback 1 Fault",
    "Load Feedback 2 Fault",
    "IGBTs Current High Difference",
]

list_4p_hard_interlocks = [
    "Load Overcurrent",
    "Load Overvoltage",
    "IGBT 1 Mod 1 Overcurrent",
    "IGBT 2 Mod 1 Overcurrent",
    "IGBT 1 Mod 2 Overcurrent",
    "IGBT 2 Mod 2 Overcurrent",
    "IGBT 1 Mod 3 Overcurrent",
    "IGBT 2 Mod 3 Overcurrent",
    "IGBT 1 Mod 4 Overcurrent",
    "IGBT 2 Mod 4 Overcurrent",
    "Welded Contactor Mod 1 Fault",
    "Welded Contactor Mod 2 Fault",
    "Welded Contactor Mod 3 Fault",
    "Welded Contactor Mod 4 Fault",
    "Opened Contactor Mod 1 Fault",
    "Opened Contactor Mod 2 Fault",
    "Opened Contactor Mod 3 Fault",
    "Opened Contactor Mod 4 Fault",
    "DCLink Mod 1 Overvoltage",
    "DCLink Mod 2 Overvoltage",
    "DCLink Mod 3 Overvoltage",
    "DCLink Mod 4 Overvoltage",
    "DCLink Mod 1 Undervoltage",
    "DCLink Mod 2 Undervoltage",
    "DCLink Mod 3 Undervoltage",
    "DCLink Mod 4 Undervoltage",
    "IIB Mod 1 Itlk",
    "IIB Mod 2 Itlk",
    "IIB Mod 3 Itlk",
    "IIB Mod 4 Itlk",
]

list_4p_iib_interlocks = list_iib_interlocks
list_4p_iib_alarms = list_iib_alarms

# FAP-2P2S
list_2p2s_soft_interlocks = [
    "DCCT 1 Fault",
    "DCCT 2 Fault",
    "DCCT High Difference",
    "Load Feedback 1 Fault",
    "Load Feedback 2 Fault",
    "Arms High Difference",
    "IGBTs Current High Difference",
    "Complementary PS Interlock",
]

list_2p2s_hard_interlocks = [
    "Load Overcurrent",
    "IGBT 1 Mod 1 Overcurrent",
    "IGBT 2 Mod 1 Overcurrent",
    "IGBT 1 Mod 2 Overcurrent",
    "IGBT 2 Mod 2 Overcurrent",
    "IGBT 1 Mod 3 Overcurrent",
    "IGBT 2 Mod 3 Overcurrent",
    "IGBT 1 Mod 4 Overcurrent",
    "IGBT 2 Mod 4 Overcurrent",
    "Welded Contactor Mod 1 Fault",
    "Welded Contactor Mod 2 Fault",
    "Welded Contactor Mod 3 Fault",
    "Welded Contactor Mod 4 Fault",
    "Opened Contactor Mod 1 Fault",
    "Opened Contactor Mod 2 Fault",
    "Opened Contactor Mod 3 Fault",
    "Opened Contactor Mod 4 Fault",
    "DCLink Mod 1 Overvoltage",
    "DCLink Mod 2 Overvoltage",
    "DCLink Mod 3 Overvoltage",
    "DCLink Mod 4 Overvoltage",
    "DCLink Mod 1 Undervoltage",
    "DCLink Mod 2 Undervoltage",
    "DCLink Mod 3 Undervoltage",
    "DCLink Mod 4 Undervoltage",
    "IIB Mod 1 Itlk",
    "IIB Mod 2 Itlk",
    "IIB Mod 3 Itlk",
    "IIB Mod 4 Itlk",
    "Arm 1 Overcurrent",
    "Arm 2 Overcurrent",
]

list_2p2s_iib_interlocks = list_iib_interlocks
list_2p2s_iib_alarms = list_iib_alarms

# FAP 225A
list_225A_soft_interlocks = ["IGBTs Current High Difference"]

list_225A_hard_interlocks = [
    "Load Overcurrent",
    "DCLink Contactor Fault",
    "IGBT 1 Overcurrent",
    "IGBT 2 Overcurrent",
]

bsmp = {
    "i_load_mean": {"addr": 33, "format": "f", "size": 4, "egu": "A"},
    "i_load1": {"addr": 34, "format": "f", "size": 4, "egu": "A"},
    "i_load2": {"addr": 35, "format": "f", "size": 4, "egu": "A"},
    "v_dclink": {"addr": 36, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1": {"addr": 37, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2": {"addr": 38, "format": "f", "size": 4, "egu": "A"},
    "duty_cycle_1": {"addr": 39, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2": {"addr": 40, "format": "f", "size": 4, "egu": "p.u."},
    "duty_diff": {"addr": 41, "format": "f", "size": 4, "egu": "p.u."},
    "v_input_iib": {"addr": 42, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib": {"addr": 43, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib": {"addr": 44, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib": {"addr": 45, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib": {"addr": 46, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib": {"addr": 47, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib": {"addr": 48, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib": {"addr": 49, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib": {"addr": 50, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib": {"addr": 51, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib": {"addr": 52, "format": "f", "size": 4, "egu": "°C"},
    "i_leakage_iib": {"addr": 53, "format": "f", "size": 4, "egu": "A"},
    "temp_board_iib": {"addr": 54, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib": {"addr": 55, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks": {"addr": 56, "format": "I", "size": 4, "egu": ""},
    "iib_alarms": {"addr": 57, "format": "I", "size": 4, "egu": ""},
    "ps_alarms": {"addr": 58, "format": "I", "size": 4, "egu": ""},
}

bsmp_4p = {
    "i_load_mean": {"addr": 33, "format": "f", "size": 4, "egu": "A"},
    "i_load1": {"addr": 34, "format": "f", "size": 4, "egu": "A"},
    "i_load2": {"addr": 35, "format": "f", "size": 4, "egu": "A"},
    "v_load": {"addr": 36, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_1": {"addr": 37, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_1": {"addr": 38, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_1_2": {"addr": 39, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_2": {"addr": 40, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_1_3": {"addr": 41, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_3": {"addr": 42, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_1_4": {"addr": 43, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_4": {"addr": 44, "format": "f", "size": 4, "egu": "A"},
    "v_dclink_1": {"addr": 45, "format": "f", "size": 4, "egu": "V"},
    "v_dclink_2": {"addr": 46, "format": "f", "size": 4, "egu": "V"},
    "v_dclink_3": {"addr": 47, "format": "f", "size": 4, "egu": "V"},
    "v_dclink_4": {"addr": 48, "format": "f", "size": 4, "egu": "V"},
    "duty_mean": {"addr": 49, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_1": {"addr": 50, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_1": {"addr": 51, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_2": {"addr": 52, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_2": {"addr": 53, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_3": {"addr": 54, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_3": {"addr": 55, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_4": {"addr": 56, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_4": {"addr": 57, "format": "f", "size": 4, "egu": "p.u."},
    "i_leakage": {"addr": 58, "format": "f", "size": 4, "egu": "A"},
    "v_input_iib_1": {"addr": 59, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_1": {"addr": 60, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_1": {"addr": 61, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_1": {"addr": 62, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_1": {"addr": 63, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_1": {"addr": 64, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_1": {"addr": 65, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_1": {"addr": 66, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_1": {"addr": 67, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_1": {"addr": 68, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_1": {"addr": 69, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_1": {"addr": 70, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_1": {"addr": 71, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_1": {"addr": 72, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_1": {"addr": 73, "format": "I", "size": 4, "egu": ""},
    "v_input_iib_2": {"addr": 74, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_2": {"addr": 75, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_2": {"addr": 76, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_2": {"addr": 77, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_2": {"addr": 78, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_2": {"addr": 79, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_2": {"addr": 80, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_2": {"addr": 81, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_2": {"addr": 82, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_2": {"addr": 83, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_2": {"addr": 84, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_2": {"addr": 85, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_2": {"addr": 86, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_2": {"addr": 87, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_2": {"addr": 88, "format": "I", "size": 4, "egu": ""},
    "v_input_iib_3": {"addr": 89, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_3": {"addr": 90, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_3": {"addr": 91, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_3": {"addr": 92, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_3": {"addr": 93, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_3": {"addr": 94, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_3": {"addr": 95, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_3": {"addr": 96, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_3": {"addr": 97, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_3": {"addr": 98, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_3": {"addr": 99, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_3": {"addr": 100, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_3": {"addr": 101, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_3": {"addr": 102, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_3": {"addr": 103, "format": "I", "size": 4, "egu": ""},
    "v_input_iib_4": {"addr": 104, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_4": {"addr": 105, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_4": {"addr": 106, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_4": {"addr": 107, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_4": {"addr": 108, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_4": {"addr": 109, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_4": {"addr": 110, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_4": {"addr": 111, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_4": {"addr": 112, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_4": {"addr": 113, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_4": {"addr": 114, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_4": {"addr": 115, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_4": {"addr": 116, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_4": {"addr": 117, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_4": {"addr": 118, "format": "I", "size": 4, "egu": ""},
    "ps_alarms": {"addr": 119, "format": "I", "size": 4, "egu": ""},
}

bsmp_2p2s = {
    "i_load_mean": {"addr": 33, "format": "f", "size": 4, "egu": "A"},
    "i_load1": {"addr": 34, "format": "f", "size": 4, "egu": "A"},
    "i_load2": {"addr": 35, "format": "f", "size": 4, "egu": "A"},
    "i_arm_1": {"addr": 36, "format": "f", "size": 4, "egu": "A"},
    "i_arm_2": {"addr": 37, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_1_1": {"addr": 38, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_1": {"addr": 39, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_1_2": {"addr": 40, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_2": {"addr": 41, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_1_3": {"addr": 42, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_3": {"addr": 43, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_1_4": {"addr": 44, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_4": {"addr": 45, "format": "f", "size": 4, "egu": "A"},
    "i_mod_1": {"addr": 46, "format": "f", "size": 4, "egu": "A"},
    "i_mod_2": {"addr": 47, "format": "f", "size": 4, "egu": "A"},
    "i_mod_3": {"addr": 48, "format": "f", "size": 4, "egu": "A"},
    "i_mod_4": {"addr": 49, "format": "f", "size": 4, "egu": "A"},
    "v_dclink_1": {"addr": 50, "format": "f", "size": 4, "egu": "V"},
    "v_dclink_2": {"addr": 51, "format": "f", "size": 4, "egu": "V"},
    "v_dclink_3": {"addr": 52, "format": "f", "size": 4, "egu": "V"},
    "v_dclink_4": {"addr": 53, "format": "f", "size": 4, "egu": "V"},
    "duty_mean": {"addr": 54, "format": "f", "size": 4, "egu": "p.u."},
    "duty_arms_diff": {"addr": 55, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_1": {"addr": 56, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_1": {"addr": 57, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_2": {"addr": 58, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_2": {"addr": 59, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_3": {"addr": 60, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_3": {"addr": 61, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_1_4": {"addr": 62, "format": "f", "size": 4, "egu": "p.u."},
    "duty_cycle_2_4": {"addr": 63, "format": "f", "size": 4, "egu": "p.u."},
    "i_leakage": {"addr": 64, "format": "f", "size": 4, "egu": "A"},
    "v_input_iib_1": {"addr": 65, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_1": {"addr": 66, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_1": {"addr": 67, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_1": {"addr": 68, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_1": {"addr": 69, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_1": {"addr": 70, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_1": {"addr": 71, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_1": {"addr": 72, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_1": {"addr": 73, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_1": {"addr": 74, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_1": {"addr": 75, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_1": {"addr": 76, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_1": {"addr": 77, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_1": {"addr": 78, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_1": {"addr": 79, "format": "I", "size": 4, "egu": ""},
    "v_input_iib_2": {"addr": 80, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_2": {"addr": 81, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_2": {"addr": 82, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_2": {"addr": 83, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_2": {"addr": 84, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_2": {"addr": 85, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_2": {"addr": 86, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_2": {"addr": 87, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_2": {"addr": 88, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_2": {"addr": 89, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_2": {"addr": 90, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_2": {"addr": 91, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_2": {"addr": 92, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_2": {"addr": 93, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_2": {"addr": 94, "format": "I", "size": 4, "egu": ""},
    "v_input_iib_3": {"addr": 95, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_3": {"addr": 96, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_3": {"addr": 97, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_3": {"addr": 98, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_3": {"addr": 99, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_3": {"addr": 100, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_3": {"addr": 101, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_3": {"addr": 102, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_3": {"addr": 103, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_3": {"addr": 104, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_3": {"addr": 105, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_3": {"addr": 106, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_3": {"addr": 107, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_3": {"addr": 108, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_3": {"addr": 109, "format": "I", "size": 4, "egu": ""},
    "v_input_iib_4": {"addr": 110, "format": "f", "size": 4, "egu": "V"},
    "v_output_iib_4": {"addr": 111, "format": "f", "size": 4, "egu": "V"},
    "i_igbt_1_iib_4": {"addr": 112, "format": "f", "size": 4, "egu": "A"},
    "i_igbt_2_iib_4": {"addr": 113, "format": "f", "size": 4, "egu": "A"},
    "temp_igbt_1_iib_4": {"addr": 114, "format": "f", "size": 4, "egu": "°C"},
    "temp_igbt_2_iib_4": {"addr": 115, "format": "f", "size": 4, "egu": "°C"},
    "v_driver_iib_4": {"addr": 116, "format": "f", "size": 4, "egu": "V"},
    "i_driver_1_iib_4": {"addr": 117, "format": "f", "size": 4, "egu": "A"},
    "i_driver_2_iib_4": {"addr": 118, "format": "f", "size": 4, "egu": "A"},
    "temp_inductor_iib_4": {"addr": 119, "format": "f", "size": 4, "egu": "°C"},
    "temp_heatsink_iib_4": {"addr": 120, "format": "f", "size": 4, "egu": "°C"},
    "temp_board_iib_4": {"addr": 121, "format": "f", "size": 4, "egu": "°C"},
    "rh_iib_4": {"addr": 122, "format": "f", "size": 4, "egu": "%"},
    "iib_interlocks_4": {"addr": 123, "format": "I", "size": 4, "egu": ""},
    "iib_alarms_4": {"addr": 124, "format": "I", "size": 4, "egu": ""},
    "ps_alarms": {"addr": 125, "format": "I", "size": 4, "egu": ""},
}
